==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/NsgReferenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.NsgReferenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Defines reference to NSG.
 * @property sourceArmResourceId Gets the ARM resource ID of the tracked resource being referenced.
 */
public data class NsgReferenceArgs(
    public val sourceArmResourceId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.NsgReferenceArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.NsgReferenceArgs =
        com.pulumi.azurenative.migrate.inputs.NsgReferenceArgs.builder()
            .sourceArmResourceId(sourceArmResourceId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NsgReferenceArgs].
 */
@PulumiTagMarker
public class NsgReferenceArgsBuilder internal constructor() {
    private var sourceArmResourceId: Output<String>? = null

    /**
     * @param value Gets the ARM resource ID of the tracked resource being referenced.
     */
    @JvmName("fydtlnrhjckfpbmt")
    public suspend fun sourceArmResourceId(`value`: Output<String>) {
        this.sourceArmResourceId = value
    }

    /**
     * @param value Gets the ARM resource ID of the tracked resource being referenced.
     */
    @JvmName("kkrqnukfylajyrep")
    public suspend fun sourceArmResourceId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceArmResourceId = mapped
    }

    internal fun build(): NsgReferenceArgs = NsgReferenceArgs(
        sourceArmResourceId = sourceArmResourceId ?: throw PulumiNullFieldException("sourceArmResourceId"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/NsgReferenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.NsgReferenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Defines reference to NSG.
 * @property sourceArmResourceId Gets the ARM resource ID of the tracked resource being referenced.
 */
public data class NsgReferenceArgs(
    public val sourceArmResourceId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.NsgReferenceArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.NsgReferenceArgs =
        com.pulumi.azurenative.migrate.inputs.NsgReferenceArgs.builder()
            .sourceArmResourceId(sourceArmResourceId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NsgReferenceArgs].
 */
@PulumiTagMarker
public class NsgReferenceArgsBuilder internal constructor() {
    private var sourceArmResourceId: Output<String>? = null

    /**
     * @param value Gets the ARM resource ID of the tracked resource being referenced.
     */
    @JvmName("mbcdhfufheglcbux")
    public suspend fun sourceArmResourceId(`value`: Output<String>) {
        this.sourceArmResourceId = value
    }

    /**
     * @param value Gets the ARM resource ID of the tracked resource being referenced.
     */
    @JvmName("lvtquhskyhaypeww")
    public suspend fun sourceArmResourceId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceArmResourceId = mapped
    }

    internal fun build(): NsgReferenceArgs = NsgReferenceArgs(
        sourceArmResourceId = sourceArmResourceId ?: throw PulumiNullFieldException("sourceArmResourceId"),
    )
}
